"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PackageUpdate(google.protobuf.message.Message):
    """Self update attempt event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    PACKAGE_FIELD_NUMBER: builtins.int
    EXE_PATH_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Update dbt to this version (e.g. 1.2.3) [default: latest version]"""
    package: builtins.str
    """Package to update (e.g. dbt) [default: dbt]"""
    exe_path: builtins.str
    """The discovered path to the dbt executable"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        package: builtins.str = ...,
        exe_path: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_exe_path", b"_exe_path", "exe_path", b"exe_path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_exe_path", b"_exe_path", "exe_path", b"exe_path", "package", b"package", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_exe_path", b"_exe_path"]) -> typing.Literal["exe_path"] | None: ...

Global___PackageUpdate: typing_extensions.TypeAlias = PackageUpdate
