# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/artifact/artifact.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=dbtlabs/proto/public/v1/events/fusion/artifact/artifact.proto\x12 v1.public.events.fusion.artifact\"o\n\x0f\x41rtifactWritten\x12\x15\n\rrelative_path\x18\x01 \x01(\t\x12\x45\n\rartifact_type\x18\x02 \x01(\x0e\x32..v1.public.events.fusion.artifact.ArtifactType*\x89\x01\n\x0c\x41rtifactType\x12\x1d\n\x19\x41RTIFACT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x41RTIFACT_TYPE_MANIFEST\x10\x01\x12#\n\x1f\x41RTIFACT_TYPE_SEMANTIC_MANIFEST\x10\x02\x12\x19\n\x15\x41RTIFACT_TYPE_CATALOG\x10\x03\x42\x43ZAgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/artifactb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.artifact.artifact_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/artifact'
  _globals['_ARTIFACTTYPE']._serialized_start=213
  _globals['_ARTIFACTTYPE']._serialized_end=350
  _globals['_ARTIFACTWRITTEN']._serialized_start=99
  _globals['_ARTIFACTWRITTEN']._serialized_end=210
# @@protoc_insertion_point(module_scope)
