"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnboardingScreenShown(google.protobuf.message.Message):
    """Onboarding step event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCREEN_FIELD_NUMBER: builtins.int
    screen: dbtlabs.proto.public.v1.events.fusion_pb2.OnboardingScreen.ValueType
    """Onboarding screen identifier"""
    def __init__(
        self,
        *,
        screen: dbtlabs.proto.public.v1.events.fusion_pb2.OnboardingScreen.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["screen", b"screen"]) -> None: ...

Global___OnboardingScreenShown: typing_extensions.TypeAlias = OnboardingScreenShown
