# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x12*v1.public.common.vortex_telemetry_contexts\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xd1\x02\n\x1eVortexTelemetryDbtCloudContext\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x01(\t\x12\"\n\x1asnowplow_domain_session_id\x18\x03 \x01(\t\x12\x1f\n\x17snowplow_domain_user_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x14\n\x0creferrer_url\x18\x06 \x01(\t\x12\x1c\n\x14\x64\x62t_cloud_account_id\x18\x07 \x01(\t\x12$\n\x1c\x64\x62t_cloud_account_identifier\x18\x08 \x01(\t\x12\x1c\n\x14\x64\x62t_cloud_project_id\x18\t \x01(\t\x12 \n\x18\x64\x62t_cloud_environment_id\x18\n \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\x0b \x01(\tBMZKgithub.com/dbt-labs/proto-golang/v1/public/common/vortex_telemetry_contextsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZKgithub.com/dbt-labs/proto-golang/v1/public/common/vortex_telemetry_contexts'
  _globals['_VORTEXTELEMETRYDBTCLOUDCONTEXT']._serialized_start=156
  _globals['_VORTEXTELEMETRYDBTCLOUDCONTEXT']._serialized_end=493
# @@protoc_insertion_point(module_scope)
