"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import dbtlabs.proto.public.v1.events.vortex_pb2
import dbtlabs.proto.public.v1.fields.vscode_types_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExtensionActivated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    OS_NAME_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    INIT_SUCCESS_FIELD_NUMBER: builtins.int
    INIT_ERROR_FIELD_NUMBER: builtins.int
    INIT_ERROR_DETAIL_FIELD_NUMBER: builtins.int
    INIT_DURATION_MS_FIELD_NUMBER: builtins.int
    IS_LSP_INSTALLED_FIELD_NUMBER: builtins.int
    IS_FUSION_INSTALLED_FIELD_NUMBER: builtins.int
    DBT_VERSION_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    MODELS_COUNT_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    os_name: builtins.str
    """os name"""
    os_version: builtins.str
    """os version"""
    init_success: builtins.bool
    """whether the extension was able to initialize successfully"""
    init_error: builtins.str
    """type of initializion error, if an error occurred at initialization"""
    init_error_detail: builtins.str
    """detailed error message, if an error occurred at initialization"""
    init_duration_ms: builtins.int
    """duration of the initialization in milliseconds"""
    is_lsp_installed: builtins.bool
    """does the user have LSP installed"""
    is_fusion_installed: builtins.bool
    """does the user have fusion installed"""
    dbt_version: builtins.str
    """the version of dbt used in the project"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    models_count: builtins.int
    """project models count"""
    adapter_type: builtins.str
    """the type of adapter used in the project (snowflake, bigquery, etc)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        os_name: builtins.str = ...,
        os_version: builtins.str = ...,
        init_success: builtins.bool = ...,
        init_error: builtins.str = ...,
        init_error_detail: builtins.str = ...,
        init_duration_ms: builtins.int = ...,
        is_lsp_installed: builtins.bool = ...,
        is_fusion_installed: builtins.bool = ...,
        dbt_version: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        models_count: builtins.int = ...,
        adapter_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "dbt_version", b"dbt_version", "editor", b"editor", "enrichment", b"enrichment", "init_duration_ms", b"init_duration_ms", "init_error", b"init_error", "init_error_detail", b"init_error_detail", "init_success", b"init_success", "is_fusion_installed", b"is_fusion_installed", "is_lsp_installed", b"is_lsp_installed", "models_count", b"models_count", "os_name", b"os_name", "os_version", b"os_version", "user", b"user"]) -> None: ...

Global___ExtensionActivated: typing_extensions.TypeAlias = ExtensionActivated

@typing.final
class ExtensionLspCompile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    ADAPTER_UNIQUE_ID_FIELD_NUMBER: builtins.int
    DBT_VERSION_FIELD_NUMBER: builtins.int
    COMPILE_SUCCESS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    COMPILE_TYPE_FIELD_NUMBER: builtins.int
    MODELS_COUNT_FIELD_NUMBER: builtins.int
    USER_INITIATED_FIELD_NUMBER: builtins.int
    COMPILE_CAUSE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """this is the hash of the project's name, used for anonymized telemetry"""
    adapter_type: builtins.str
    """the type of adapter used in the project (snowflake, bigquery, etc)"""
    adapter_unique_id: builtins.str
    """the unique id of the adapter used in the active profile eg. md5(hostname)"""
    dbt_version: builtins.str
    """the version of dbt used in the project"""
    compile_success: builtins.bool
    """Indicates whether the compile was successful"""
    duration_ms: builtins.int
    """duration of the compile in milliseconds"""
    compile_type: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileType.ValueType
    """the type of compile"""
    models_count: builtins.int
    """project models count"""
    user_initiated: builtins.bool
    """True if the compile was triggered by a user action (ie. saving a file)"""
    compile_cause: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileCause.ValueType
    """The event that triggered the compile"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileError]: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        project_id: builtins.str = ...,
        adapter_type: builtins.str = ...,
        adapter_unique_id: builtins.str = ...,
        dbt_version: builtins.str = ...,
        compile_success: builtins.bool = ...,
        errors: collections.abc.Iterable[dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileError] | None = ...,
        duration_ms: builtins.int = ...,
        compile_type: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileType.ValueType = ...,
        models_count: builtins.int = ...,
        user_initiated: builtins.bool = ...,
        compile_cause: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileCause.ValueType = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "adapter_unique_id", b"adapter_unique_id", "compile_cause", b"compile_cause", "compile_success", b"compile_success", "compile_type", b"compile_type", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "dbt_version", b"dbt_version", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "errors", b"errors", "models_count", b"models_count", "project_id", b"project_id", "user", b"user", "user_initiated", b"user_initiated"]) -> None: ...

Global___ExtensionLspCompile: typing_extensions.TypeAlias = ExtensionLspCompile

@typing.final
class ExtensionUserStateChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    CHANGED_TO_STATE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    changed_to_state: dbtlabs.proto.public.v1.fields.vscode_types_pb2.UserState.ValueType
    """the state the user changed to"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        changed_to_state: dbtlabs.proto.public.v1.fields.vscode_types_pb2.UserState.ValueType = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["changed_to_state", b"changed_to_state", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionUserStateChange: typing_extensions.TypeAlias = ExtensionUserStateChange

@typing.final
class ExtensionCtePreview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionCtePreview: typing_extensions.TypeAlias = ExtensionCtePreview

@typing.final
class ExtensionLineageTabClicked(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionLineageTabClicked: typing_extensions.TypeAlias = ExtensionLineageTabClicked

@typing.final
class ExtensionColumnLineage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionColumnLineage: typing_extensions.TypeAlias = ExtensionColumnLineage

@typing.final
class ExtensionShowCompiledFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionShowCompiledFile: typing_extensions.TypeAlias = ExtensionShowCompiledFile

@typing.final
class ExtensionModelRename(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionModelRename: typing_extensions.TypeAlias = ExtensionModelRename

@typing.final
class ExtensionColumnRename(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionColumnRename: typing_extensions.TypeAlias = ExtensionColumnRename

@typing.final
class ExtensionUsedBuildMenu(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SELECTED_COMMAND_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    selected_command: builtins.str
    """the command that the user selected"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        selected_command: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "selected_command", b"selected_command", "user", b"user"]) -> None: ...

Global___ExtensionUsedBuildMenu: typing_extensions.TypeAlias = ExtensionUsedBuildMenu

@typing.final
class ExtensionGetSupportPopupShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportPopupShown: typing_extensions.TypeAlias = ExtensionGetSupportPopupShown

@typing.final
class ExtensionGetSupportClicked(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support that was clicked"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportClicked: typing_extensions.TypeAlias = ExtensionGetSupportClicked

@typing.final
class ExtensionGetSupportFormShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormShown: typing_extensions.TypeAlias = ExtensionGetSupportFormShown

@typing.final
class ExtensionGetSupportUnverifiedNoticeShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportUnverifiedNoticeShown: typing_extensions.TypeAlias = ExtensionGetSupportUnverifiedNoticeShown

@typing.final
class ExtensionGetSupportFormSubmitted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support that was submitted"""
    success: builtins.bool
    """whether the submission was successful"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        success: builtins.bool = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "success", b"success", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormSubmitted: typing_extensions.TypeAlias = ExtensionGetSupportFormSubmitted

@typing.final
class ExtensionGetSupportFormCancelled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being cancelled"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormCancelled: typing_extensions.TypeAlias = ExtensionGetSupportFormCancelled

@typing.final
class ExtensionGetSupportPanelClosed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support panel that was closed"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportPanelClosed: typing_extensions.TypeAlias = ExtensionGetSupportPanelClosed

@typing.final
class ExtensionCompareViewed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionCompareViewed: typing_extensions.TypeAlias = ExtensionCompareViewed

@typing.final
class ExtensionCompareStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    COMPARE_ID_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    compare_id: builtins.str
    """anonymized identifier for this compare session"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        compare_id: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compare_id", b"compare_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionCompareStarted: typing_extensions.TypeAlias = ExtensionCompareStarted

@typing.final
class ExtensionCompareFinished(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    COMPARE_ID_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    COMPARE_SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    compare_id: builtins.str
    """anonymized identifier for this compare session"""
    duration_ms: builtins.int
    """duration of the compare operation in milliseconds"""
    compare_success: builtins.bool
    """whether the compare operation completed successfully"""
    failure_reason: builtins.str
    """sanitized description of the failure, if any"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        compare_id: builtins.str = ...,
        duration_ms: builtins.int = ...,
        compare_success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compare_id", b"compare_id", "compare_success", b"compare_success", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "failure_reason", b"failure_reason", "user", b"user"]) -> None: ...

Global___ExtensionCompareFinished: typing_extensions.TypeAlias = ExtensionCompareFinished

@typing.final
class ExtensionRegistrationMessageDismissed(google.protobuf.message.Message):
    """Emited if the user dismiss a message prompting them to register the extension?"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationMessageDismissed: typing_extensions.TypeAlias = ExtensionRegistrationMessageDismissed

@typing.final
class ExtensionRegisterStarted(google.protobuf.message.Message):
    """Emitted if the user starts the registration flow. There are several UI affordances to do this."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    TRIGGER_METHOD_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType
    """which registration path will be used"""
    correlation_id: builtins.str
    """identifier to correlate related registration events"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "trigger_method", b"trigger_method", "user", b"user"]) -> None: ...

Global___ExtensionRegisterStarted: typing_extensions.TypeAlias = ExtensionRegisterStarted

@typing.final
class ExtensionRegistrationUrlAttempted(google.protobuf.message.Message):
    """In vscode, extensions cannot automatically open external URLs
    Instead, vscode shows the user a modal with the URL
    The user can pick Open, Trust Domain, Copy, or Cancel
    Open or Trust Domain result in the URL opening, and url_opened will be true
    Cancel or Copy result in url_opened false
    If the user copied the URL, they may paste it into a browser to continue registration
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    URL_OPENED_FIELD_NUMBER: builtins.int
    OAUTH_PARAMS_INCLUDED_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    url_opened: builtins.bool
    """whether the user opened the URL (Open/Trust = true, Cancel/Copy = false)"""
    oauth_params_included: builtins.bool
    """whether oauth parameters were included in the URL"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        url_opened: builtins.bool = ...,
        oauth_params_included: builtins.bool = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "oauth_params_included", b"oauth_params_included", "url_opened", b"url_opened", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationUrlAttempted: typing_extensions.TypeAlias = ExtensionRegistrationUrlAttempted

@typing.final
class ExtensionRegistrationCompleted(google.protobuf.message.Message):
    """Emitted when the user successfully completes registration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    REGISTRATION_METHOD_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_HOST_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType
    """the actual registration method used"""
    duration_ms: builtins.int
    """duration of the registration flow in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    account_id: builtins.str
    """dbt Cloud account ID the user registered with"""
    user_id: builtins.str
    """dbt Cloud user ID for the registered user"""
    account_host: builtins.str
    """dbt Cloud hostname (e.g., cloud.getdbt.com)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType = ...,
        duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
        account_id: builtins.str = ...,
        user_id: builtins.str = ...,
        account_host: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["account_host", b"account_host", "account_id", b"account_id", "correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "registration_method", b"registration_method", "user", b"user", "user_id", b"user_id"]) -> None: ...

Global___ExtensionRegistrationCompleted: typing_extensions.TypeAlias = ExtensionRegistrationCompleted

@typing.final
class ExtensionRegistrationTimedOut(google.protobuf.message.Message):
    """Once a user starts registration, they must complete it within 10 minutes
    After 10 minutes, the auth server shuts down and we emit this event
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    TRIGGER_METHOD_FIELD_NUMBER: builtins.int
    TIMEOUT_DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType
    """the registration trigger method that timed out (dbt_cloud.yml or web)"""
    timeout_duration_ms: builtins.int
    """duration until timeout in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType = ...,
        timeout_duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "timeout_duration_ms", b"timeout_duration_ms", "trigger_method", b"trigger_method", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationTimedOut: typing_extensions.TypeAlias = ExtensionRegistrationTimedOut

@typing.final
class ExtensionRegistrationErrored(google.protobuf.message.Message):
    """Emitted when an error occurs during registration
    These are most likely to be caused by issues in code (bugs, unanticipated cases, regressiones)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    REGISTRATION_METHOD_FIELD_NUMBER: builtins.int
    ERROR_TYPE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType
    """the registration method that errored (use UNSPECIFIED if not yet known)"""
    error_type: builtins.str
    """type/category of error that occurred"""
    error_message: builtins.str
    """sanitized error message (no PII)"""
    duration_ms: builtins.int
    """duration until error in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType = ...,
        error_type: builtins.str = ...,
        error_message: builtins.str = ...,
        duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "error_message", b"error_message", "error_type", b"error_type", "event_id", b"event_id", "registration_method", b"registration_method", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationErrored: typing_extensions.TypeAlias = ExtensionRegistrationErrored
