# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/invocation/invocation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.process import process_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_process_dot_process__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/invocation/invocation.proto\x12\"v1.public.events.fusion.invocation\x1a;dbtlabs/proto/public/v1/events/fusion/process/process.proto\"\xda\x03\n\x11InvocationMetrics\x12\x19\n\x0ctotal_errors\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x1b\n\x0etotal_warnings\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12 \n\x13\x61utofix_suggestions\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x63\n\x10node_type_counts\x18\x04 \x03(\x0b\x32I.v1.public.events.fusion.invocation.InvocationMetrics.NodeTypeCountsEntry\x12^\n\rstatus_counts\x18\x05 \x03(\x0b\x32G.v1.public.events.fusion.invocation.InvocationMetrics.StatusCountsEntry\x1a\x35\n\x13NodeTypeCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x33\n\x11StatusCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x42\x0f\n\r_total_errorsB\x11\n\x0f_total_warningsB\x16\n\x14_autofix_suggestions\"\xc9\x06\n\x12InvocationEvalArgs\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x19\n\x0cprofiles_dir\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15packages_install_path\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06target\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07profile\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x0c\n\x04vars\x18\x06 \x01(\t\x12\x12\n\x05limit\x18\x07 \x01(\x04H\x04\x88\x01\x01\x12\x18\n\x0bnum_threads\x18\x08 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08selector\x18\t \x01(\tH\x06\x88\x01\x01\x12\x0e\n\x06select\x18\n \x03(\t\x12\x0f\n\x07\x65xclude\x18\x0b \x03(\t\x12\x1f\n\x12indirect_selection\x18\x0c \x01(\tH\x07\x88\x01\x01\x12\x13\n\x0boutput_keys\x18\r \x03(\t\x12\x16\n\x0eresource_types\x18\x0e \x03(\t\x12\x1e\n\x16\x65xclude_resource_types\x18\x0f \x03(\t\x12\x12\n\x05\x64\x65\x62ug\x18\x10 \x01(\x08H\x08\x88\x01\x01\x12\x17\n\nlog_format\x18\x11 \x01(\tH\t\x88\x01\x01\x12\x16\n\tlog_level\x18\x12 \x01(\tH\n\x88\x01\x01\x12\x15\n\x08log_path\x18\x13 \x01(\tH\x0b\x88\x01\x01\x12\x18\n\x0btarget_path\x18\x14 \x01(\tH\x0c\x88\x01\x01\x12\x18\n\x0bproject_dir\x18\x15 \x01(\tH\r\x88\x01\x01\x12\x12\n\x05quiet\x18\x16 \x01(\x08H\x0e\x88\x01\x01\x12\x17\n\nwrite_json\x18\x17 \x01(\x08H\x0f\x88\x01\x01\x12\x1a\n\rwrite_catalog\x18\x18 \x01(\x08H\x10\x88\x01\x01\x42\x0f\n\r_profiles_dirB\x18\n\x16_packages_install_pathB\t\n\x07_targetB\n\n\x08_profileB\x08\n\x06_limitB\x0e\n\x0c_num_threadsB\x0b\n\t_selectorB\x15\n\x13_indirect_selectionB\x08\n\x06_debugB\r\n\x0b_log_formatB\x0c\n\n_log_levelB\x0b\n\t_log_pathB\x0e\n\x0c_target_pathB\x0e\n\x0c_project_dirB\x08\n\x06_quietB\r\n\x0b_write_jsonB\x10\n\x0e_write_catalog\"\xbb\x02\n\nInvocation\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x13\n\x0braw_command\x18\x02 \x01(\t\x12I\n\teval_args\x18\x03 \x01(\x0b\x32\x36.v1.public.events.fusion.invocation.InvocationEvalArgs\x12>\n\x0cprocess_info\x18\x04 \x01(\x0b\x32(.v1.public.events.fusion.process.Process\x12\x46\n\x07metrics\x18\x05 \x01(\x0b\x32\x35.v1.public.events.fusion.invocation.InvocationMetrics\x12\x1b\n\x0eparent_span_id\x18\x06 \x01(\x04H\x00\x88\x01\x01\x42\x11\n\x0f_parent_span_idBEZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/invocationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.invocation.invocation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/invocation'
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._loaded_options = None
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._loaded_options = None
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_INVOCATIONMETRICS']._serialized_start=167
  _globals['_INVOCATIONMETRICS']._serialized_end=641
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_start=475
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_end=528
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_start=530
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_end=581
  _globals['_INVOCATIONEVALARGS']._serialized_start=644
  _globals['_INVOCATIONEVALARGS']._serialized_end=1485
  _globals['_INVOCATION']._serialized_start=1488
  _globals['_INVOCATION']._serialized_end=1803
# @@protoc_insertion_point(module_scope)
