"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Process(google.protobuf.message.Message):
    """Process-wide attributes for a telemetry-emitting process."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HOST_OS_FIELD_NUMBER: builtins.int
    HOST_ARCH_FIELD_NUMBER: builtins.int
    package: builtins.str
    """Name of the emitting package, e.g. "dbt" or "dbt-lsp"."""
    version: builtins.str
    """Version of the emitting package, e.g. "v2.0.0"."""
    host_os: builtins.str
    """Host operating system, e.g. "linux", "darwin", "windows"."""
    host_arch: builtins.str
    """Host architecture, e.g. "x86_64", "aarch64"."""
    def __init__(
        self,
        *,
        package: builtins.str = ...,
        version: builtins.str = ...,
        host_os: builtins.str = ...,
        host_arch: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_arch", b"host_arch", "host_os", b"host_os", "package", b"package", "version", b"version"]) -> None: ...

Global___Process: typing_extensions.TypeAlias = Process
