# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/metadata_telemetry.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/metadata_telemetry.proto\x12#v1.public.events.metadata_telemetry\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xa6\x02\n\x07Handoff\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12[\n\x07\x63ontext\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x14\n\x0chandoff_from\x18\x03 \x01(\t\x12\x12\n\nhandoff_to\x18\x04 \x01(\t\x12\x1f\n\x17is_final_handoff_action\x18\x05 \x01(\x08\x12\x16\n\x0ehandoff_action\x18\x06 \x01(\t\x12\x12\n\nasset_type\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01*E\n\x0bHandoffFrom\x12\x1c\n\x18HANDOFF_FROM_UNSPECIFIED\x10\x00\x12\x18\n\x14HANDOFF_FROM_CATALOG\x10\x01*\x83\x01\n\tHandoffTo\x12\x1a\n\x16HANDOFF_TO_UNSPECIFIED\x10\x00\x12\x16\n\x12HANDOFF_TO_CATALOG\x10\x01\x12\x12\n\x0eHANDOFF_TO_IDE\x10\x02\x12\x15\n\x11HANDOFF_TO_CANVAS\x10\x03\x12\x17\n\x13HANDOFF_TO_INSIGHTS\x10\x04*\xe5\x02\n\x10HandoffAssetType\x12\"\n\x1eHANDOFF_ASSET_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cHANDOFF_ASSET_TYPE_DBT_MODEL\x10\x01\x12!\n\x1dHANDOFF_ASSET_TYPE_DBT_SOURCE\x10\x02\x12#\n\x1fHANDOFF_ASSET_TYPE_DBT_SNAPSHOT\x10\x03\x12\x1f\n\x1bHANDOFF_ASSET_TYPE_DBT_SEED\x10\x04\x12!\n\x1dHANDOFF_ASSET_TYPE_DBT_METRIC\x10\x05\x12&\n\"HANDOFF_ASSET_TYPE_DBT_SAVED_QUERY\x10\x06\x12+\n\'HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_TABLE\x10\x07\x12*\n&HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_VIEW\x10\x08\x42\x46ZDgithub.com/dbt-labs/proto-golang/v1/public/events/metadata_telemetryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.metadata_telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZDgithub.com/dbt-labs/proto-golang/v1/public/events/metadata_telemetry'
  _globals['_HANDOFF']._loaded_options = None
  _globals['_HANDOFF']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFFROM']._serialized_start=555
  _globals['_HANDOFFFROM']._serialized_end=624
  _globals['_HANDOFFTO']._serialized_start=627
  _globals['_HANDOFFTO']._serialized_end=758
  _globals['_HANDOFFASSETTYPE']._serialized_start=761
  _globals['_HANDOFFASSETTYPE']._serialized_end=1118
  _globals['_HANDOFF']._serialized_start=259
  _globals['_HANDOFF']._serialized_end=553
# @@protoc_insertion_point(module_scope)
