"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

Global___EventInfo: typing_extensions.TypeAlias = EventInfo

@typing.final
class GenericMessage(google.protobuf.message.Message):
    """GenericMessage, used for deserializing only"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["info", b"info"]) -> None: ...

Global___GenericMessage: typing_extensions.TypeAlias = GenericMessage

@typing.final
class BehaviorChangeEvent(google.protobuf.message.Message):
    """D - Deprecations

    D018
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAG_NAME_FIELD_NUMBER: builtins.int
    FLAG_SOURCE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCS_URL_FIELD_NUMBER: builtins.int
    flag_name: builtins.str
    flag_source: builtins.str
    description: builtins.str
    docs_url: builtins.str
    def __init__(
        self,
        *,
        flag_name: builtins.str = ...,
        flag_source: builtins.str = ...,
        description: builtins.str = ...,
        docs_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "docs_url", b"docs_url", "flag_name", b"flag_name", "flag_source", b"flag_source"]) -> None: ...

Global___BehaviorChangeEvent: typing_extensions.TypeAlias = BehaviorChangeEvent

@typing.final
class BehaviorChangeEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___BehaviorChangeEvent: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___BehaviorChangeEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___BehaviorChangeEventMsg: typing_extensions.TypeAlias = BehaviorChangeEventMsg

@typing.final
class GetMetaKeyDeprecation(google.protobuf.message.Message):
    """D041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_KEY_FIELD_NUMBER: builtins.int
    meta_key: builtins.str
    def __init__(
        self,
        *,
        meta_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["meta_key", b"meta_key"]) -> None: ...

Global___GetMetaKeyDeprecation: typing_extensions.TypeAlias = GetMetaKeyDeprecation

@typing.final
class GetMetaKeyDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___GetMetaKeyDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___GetMetaKeyDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GetMetaKeyDeprecationMsg: typing_extensions.TypeAlias = GetMetaKeyDeprecationMsg

@typing.final
class RetryExternalCall(google.protobuf.message.Message):
    """M - Deps generation

    M020
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTEMPT_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    attempt: builtins.int
    max: builtins.int
    def __init__(
        self,
        *,
        attempt: builtins.int = ...,
        max: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attempt", b"attempt", "max", b"max"]) -> None: ...

Global___RetryExternalCall: typing_extensions.TypeAlias = RetryExternalCall

@typing.final
class RetryExternalCallMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RetryExternalCall: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RetryExternalCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RetryExternalCallMsg: typing_extensions.TypeAlias = RetryExternalCallMsg

@typing.final
class RecordRetryException(google.protobuf.message.Message):
    """M021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___RecordRetryException: typing_extensions.TypeAlias = RecordRetryException

@typing.final
class RecordRetryExceptionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RecordRetryException: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RecordRetryException | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RecordRetryExceptionMsg: typing_extensions.TypeAlias = RecordRetryExceptionMsg

@typing.final
class GetMetaKeyWarning(google.protobuf.message.Message):
    """Q - Node execution

    Q047
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_KEY_FIELD_NUMBER: builtins.int
    meta_key: builtins.str
    def __init__(
        self,
        *,
        meta_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["meta_key", b"meta_key"]) -> None: ...

Global___GetMetaKeyWarning: typing_extensions.TypeAlias = GetMetaKeyWarning

@typing.final
class GetMetaKeyWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___GetMetaKeyWarning: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___GetMetaKeyWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GetMetaKeyWarningMsg: typing_extensions.TypeAlias = GetMetaKeyWarningMsg

@typing.final
class SystemCouldNotWrite(google.protobuf.message.Message):
    """Z - Misc

    Z005
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    path: builtins.str
    reason: builtins.str
    exc: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        reason: builtins.str = ...,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "path", b"path", "reason", b"reason"]) -> None: ...

Global___SystemCouldNotWrite: typing_extensions.TypeAlias = SystemCouldNotWrite

@typing.final
class SystemCouldNotWriteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemCouldNotWrite: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemCouldNotWrite | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemCouldNotWriteMsg: typing_extensions.TypeAlias = SystemCouldNotWriteMsg

@typing.final
class SystemExecutingCmd(google.protobuf.message.Message):
    """Z006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMD_FIELD_NUMBER: builtins.int
    @property
    def cmd(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cmd: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cmd", b"cmd"]) -> None: ...

Global___SystemExecutingCmd: typing_extensions.TypeAlias = SystemExecutingCmd

@typing.final
class SystemExecutingCmdMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemExecutingCmd: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemExecutingCmd | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemExecutingCmdMsg: typing_extensions.TypeAlias = SystemExecutingCmdMsg

@typing.final
class SystemStdOut(google.protobuf.message.Message):
    """Z007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BMSG_FIELD_NUMBER: builtins.int
    bmsg: builtins.str
    def __init__(
        self,
        *,
        bmsg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bmsg", b"bmsg"]) -> None: ...

Global___SystemStdOut: typing_extensions.TypeAlias = SystemStdOut

@typing.final
class SystemStdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemStdOut: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemStdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemStdOutMsg: typing_extensions.TypeAlias = SystemStdOutMsg

@typing.final
class SystemStdErr(google.protobuf.message.Message):
    """Z008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BMSG_FIELD_NUMBER: builtins.int
    bmsg: builtins.str
    def __init__(
        self,
        *,
        bmsg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bmsg", b"bmsg"]) -> None: ...

Global___SystemStdErr: typing_extensions.TypeAlias = SystemStdErr

@typing.final
class SystemStdErrMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemStdErr: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemStdErr | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemStdErrMsg: typing_extensions.TypeAlias = SystemStdErrMsg

@typing.final
class SystemReportReturnCode(google.protobuf.message.Message):
    """Z009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURNCODE_FIELD_NUMBER: builtins.int
    returncode: builtins.int
    def __init__(
        self,
        *,
        returncode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["returncode", b"returncode"]) -> None: ...

Global___SystemReportReturnCode: typing_extensions.TypeAlias = SystemReportReturnCode

@typing.final
class SystemReportReturnCodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemReportReturnCode: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemReportReturnCode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemReportReturnCodeMsg: typing_extensions.TypeAlias = SystemReportReturnCodeMsg

@typing.final
class Formatting(google.protobuf.message.Message):
    """Z017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___Formatting: typing_extensions.TypeAlias = Formatting

@typing.final
class FormattingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___Formatting: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___Formatting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FormattingMsg: typing_extensions.TypeAlias = FormattingMsg

@typing.final
class Note(google.protobuf.message.Message):
    """Z050"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___Note: typing_extensions.TypeAlias = Note

@typing.final
class NoteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___Note: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___Note | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoteMsg: typing_extensions.TypeAlias = NoteMsg

@typing.final
class PrintEvent(google.protobuf.message.Message):
    """Z052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___PrintEvent: typing_extensions.TypeAlias = PrintEvent

@typing.final
class PrintEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___PrintEvent: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___PrintEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PrintEventMsg: typing_extensions.TypeAlias = PrintEventMsg

@typing.final
class RecordReplayIssue(google.protobuf.message.Message):
    """Z053"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___RecordReplayIssue: typing_extensions.TypeAlias = RecordReplayIssue

@typing.final
class RecordReplayIssueMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RecordReplayIssue: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RecordReplayIssue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RecordReplayIssueMsg: typing_extensions.TypeAlias = RecordReplayIssueMsg
