# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/vscode_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dbtlabs/proto/public/v1/fields/vscode_types.proto\x12\x1dv1.public.fields.vscode_types\"u\n\x04User\x12\x1a\n\x12\x63redentials_source\x18\x01 \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x62t_cloud_hostname\x18\x03 \x01(\t\x12\x1a\n\x12registration_state\x18\x04 \x01(\t\"\x90\x01\n\x06\x45\x64itor\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nmachine_id\x18\x02 \x01(\t\x12\x16\n\x0emac_machine_id\x18\x03 \x01(\t\x12\x19\n\x11\x65xtension_version\x18\x04 \x01(\t\x12\x13\n\x0b\x65\x64itor_name\x18\x05 \x01(\t\x12\x16\n\x0e\x65\x64itor_version\x18\x06 \x01(\t\"-\n\x0c\x43ompileError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05*\x97\x01\n\tUserState\x12\x1b\n\x17USER_STATE_UNREGISTERED\x10\x00\x12\x19\n\x15USER_STATE_REGISTERED\x10\x01\x12\x17\n\x13USER_STATE_VERIFIED\x10\x02\x12\x16\n\x12USER_STATE_EXPIRED\x10\x03\x12!\n\x1dUSER_STATE_VERIFICATION_ERROR\x10\x04*(\n\x0b\x43ompileType\x12\x08\n\x04\x46ULL\x10\x00\x12\x0f\n\x0bSPECULATIVE\x10\x01*t\n\x0c\x43ompileCause\x12\x1a\n\x16\x43OMPILE_CAUSE_DID_SAVE\x10\x00\x12%\n!COMPILE_CAUSE_COMPILE_LSP_COMMAND\x10\x01\x12!\n\x1d\x43OMPILE_CAUSE_REFRESH_SOURCES\x10\x02*\x9c\x01\n\x19RegistrationTriggerMethod\x12+\n\'REGISTRATION_TRIGGER_METHOD_UNSPECIFIED\x10\x00\x12-\n)REGISTRATION_TRIGGER_METHOD_DBT_CLOUD_YML\x10\x01\x12#\n\x1fREGISTRATION_TRIGGER_METHOD_WEB\x10\x02*\xaa\x01\n\x12RegistrationMethod\x12#\n\x1fREGISTRATION_METHOD_UNSPECIFIED\x10\x00\x12%\n!REGISTRATION_METHOD_DBT_CLOUD_YML\x10\x01\x12\x1d\n\x19REGISTRATION_METHOD_OAUTH\x10\x02\x12)\n%REGISTRATION_METHOD_REGISTRATION_CODE\x10\x03\x42@Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.vscode_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_types'
  _globals['_USERSTATE']._serialized_start=398
  _globals['_USERSTATE']._serialized_end=549
  _globals['_COMPILETYPE']._serialized_start=551
  _globals['_COMPILETYPE']._serialized_end=591
  _globals['_COMPILECAUSE']._serialized_start=593
  _globals['_COMPILECAUSE']._serialized_end=709
  _globals['_REGISTRATIONTRIGGERMETHOD']._serialized_start=712
  _globals['_REGISTRATIONTRIGGERMETHOD']._serialized_end=868
  _globals['_REGISTRATIONMETHOD']._serialized_start=871
  _globals['_REGISTRATIONMETHOD']._serialized_end=1041
  _globals['_USER']._serialized_start=84
  _globals['_USER']._serialized_end=201
  _globals['_EDITOR']._serialized_start=204
  _globals['_EDITOR']._serialized_end=348
  _globals['_COMPILEERROR']._serialized_start=350
  _globals['_COMPILEERROR']._serialized_end=395
# @@protoc_insertion_point(module_scope)
