# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/list_item.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/log/list_item.proto\x12\x1bv1.public.events.fusion.log\"\x8d\x01\n\x0eListItemOutput\x12\x44\n\routput_format\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.log.ListOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\tunique_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_unique_id*\xae\x01\n\x10ListOutputFormat\x12\"\n\x1eLIST_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\x1b\n\x17LIST_OUTPUT_FORMAT_JSON\x10\x01\x12\x1f\n\x1bLIST_OUTPUT_FORMAT_SELECTOR\x10\x02\x12\x1b\n\x17LIST_OUTPUT_FORMAT_NAME\x10\x03\x12\x1b\n\x17LIST_OUTPUT_FORMAT_PATH\x10\x04\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.list_item_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_LISTOUTPUTFORMAT']._serialized_start=235
  _globals['_LISTOUTPUTFORMAT']._serialized_end=409
  _globals['_LISTITEMOUTPUT']._serialized_start=91
  _globals['_LISTITEMOUTPUT']._serialized_end=232
# @@protoc_insertion_point(module_scope)
