# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vortex.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vortex.proto\x12\x10v1.events.vortex\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\"\xab\x02\n\rVortexMessage\x12!\n\x03\x61ny\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x17vortex_event_created_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15vortex_client_sent_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1avortex_backend_received_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1bvortex_backend_processed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Z\n\x12VortexMessageBatch\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x30\n\x07payload\x18\x02 \x03(\x0b\x32\x1f.v1.events.vortex.VortexMessage\"i\n\x17VortexDeadLetterMessage\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x13\n\x0bvalue_bytes\x18\x03 \x01(\x0c\x12\x0e\n\x06reason\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x04\x80\xa7\x1d\x01\"\xc6\x01\n\x17VortexMessageEnrichment\x12\x33\n\tclient_ip\x18\x01 \x01(\x0b\x32 .v1.events.vortex.VortexClientIp\x12?\n\x0f\x63lient_platform\x18\x02 \x01(\x0b\x32&.v1.events.vortex.VortexClientPlatform\x12\x35\n\nuser_agent\x18\x03 \x01(\x0b\x32!.v1.events.vortex.VortexUserAgent\"]\n\x0eVortexClientIp\x12\n\n\x02ip\x18\x01 \x01(\t\x12\r\n\x05proxy\x18\x02 \x01(\x08\x12\x30\n\x03geo\x18\x03 \x01(\x0b\x32#.v1.events.vortex.VortexGeolocation\"|\n\x11VortexGeolocation\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\x01\x12\x11\n\tlongitude\x18\x04 \x01(\x01\x12\x10\n\x08timezone\x18\x05 \x01(\t\x12\x11\n\tcontinent\x18\x06 \x01(\t\"\xb3\x01\n\x14VortexClientPlatform\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x17\n\x0fservice_version\x18\x03 \x01(\t\x12\x0e\n\x06\x63lient\x18\x04 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x05 \x01(\t\x12\x19\n\x11\x64\x62t_proto_library\x18\x06 \x01(\t\x12!\n\x19\x64\x62t_proto_library_version\x18\x07 \x01(\t\"\x8d\x01\n\x0fVortexUserAgent\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x02 \x01(\t\x12\x17\n\x0f\x62rowser_version\x18\x03 \x01(\t\x12\n\n\x02os\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x07 \x01(\tB3Z1github.com/dbt-labs/proto-golang/v1/events/vortexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vortex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/dbt-labs/proto-golang/v1/events/vortex'
  _globals['_VORTEXDEADLETTERMESSAGE']._loaded_options = None
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_options = b'\330\246\035\004\200\247\035\001'
  _globals['_VORTEXMESSAGE']._serialized_start=179
  _globals['_VORTEXMESSAGE']._serialized_end=478
  _globals['_VORTEXMESSAGEBATCH']._serialized_start=480
  _globals['_VORTEXMESSAGEBATCH']._serialized_end=570
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_start=572
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_end=677
  _globals['_VORTEXMESSAGEENRICHMENT']._serialized_start=680
  _globals['_VORTEXMESSAGEENRICHMENT']._serialized_end=878
  _globals['_VORTEXCLIENTIP']._serialized_start=880
  _globals['_VORTEXCLIENTIP']._serialized_end=973
  _globals['_VORTEXGEOLOCATION']._serialized_start=975
  _globals['_VORTEXGEOLOCATION']._serialized_end=1099
  _globals['_VORTEXCLIENTPLATFORM']._serialized_start=1102
  _globals['_VORTEXCLIENTPLATFORM']._serialized_end=1281
  _globals['_VORTEXUSERAGENT']._serialized_start=1284
  _globals['_VORTEXUSERAGENT']._serialized_end=1425
# @@protoc_insertion_point(module_scope)
