# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/log.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.compat import otlp_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_compat_dot_otlp__pb2
from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/events/fusion/log/log.proto\x12\x1bv1.public.events.fusion.log\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/compat/otlp.proto\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xab\x03\n\nLogMessage\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13\x64\x62t_core_event_code\x18\x02 \x01(\tH\x01\x88\x01\x01\x12P\n\x18original_severity_number\x18\x03 \x01(\x0e\x32..v1.public.events.fusion.compat.SeverityNumber\x12\x1e\n\x16original_severity_text\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04\x66ile\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04line\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x05\x88\x01\x01\x12\x19\n\x0cpackage_name\x18\t \x01(\tH\x06\x88\x01\x01\x42\x07\n\x05_codeB\x16\n\x14_dbt_core_event_codeB\x0c\n\n_unique_idB\x07\n\x05_fileB\x07\n\x05_lineB\x08\n\x06_phaseB\x0f\n\r_package_name\"\xc8\x02\n\x0eUserLogMessage\x12\x10\n\x08is_print\x18\x01 \x01(\x08\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x02 \x01(\t\x12\x16\n\tunique_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x41\n\x05phase\x18\x04 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x01\x88\x01\x01\x12\x19\n\x0cpackage_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04line\x18\x06 \x01(\rH\x03\x88\x01\x01\x12\x13\n\x06\x63olumn\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x1a\n\rrelative_path\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0c\n\n_unique_idB\x08\n\x06_phaseB\x0f\n\r_package_nameB\x07\n\x05_lineB\t\n\x07_columnB\x10\n\x0e_relative_path\"\xc0\x02\n\x0fProgressMessage\x12 \n\x13\x64\x62t_core_event_code\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04\x66ile\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04line\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x05\x88\x01\x01\x42\x16\n\x14_dbt_core_event_codeB\x0e\n\x0c_descriptionB\x0c\n\n_unique_idB\x07\n\x05_fileB\x07\n\x05_lineB\x08\n\x06_phaseB>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_LOGMESSAGE']._serialized_start=199
  _globals['_LOGMESSAGE']._serialized_end=626
  _globals['_USERLOGMESSAGE']._serialized_start=629
  _globals['_USERLOGMESSAGE']._serialized_end=957
  _globals['_PROGRESSMESSAGE']._serialized_start=960
  _globals['_PROGRESSMESSAGE']._serialized_end=1280
# @@protoc_insertion_point(module_scope)
