# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/query/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/query/query.proto\x12\x1dv1.public.events.fusion.query\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xfe\x03\n\rQueryExecuted\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x10\n\x08sql_hash\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x03 \x01(\t\x12\x1e\n\x11query_description\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08query_id\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tunique_id\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x42\n\rquery_outcome\x18\x07 \x01(\x0e\x32+.v1.public.events.fusion.query.QueryOutcome\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x03\x88\x01\x01\x12(\n\x1bquery_error_adapter_message\x18\t \x01(\tH\x04\x88\x01\x01\x12$\n\x17query_error_vendor_code\x18\n \x01(\x05H\x05\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x0b \x01(\tB\x14\n\x12_query_descriptionB\x0b\n\t_query_idB\x0c\n\n_unique_idB\x08\n\x06_phaseB\x1e\n\x1c_query_error_adapter_messageB\x1a\n\x18_query_error_vendor_code*}\n\x0cQueryOutcome\x12\x1d\n\x19QUERY_OUTCOME_UNSPECIFIED\x10\x00\x12\x19\n\x15QUERY_OUTCOME_SUCCESS\x10\x01\x12\x17\n\x13QUERY_OUTCOME_ERROR\x10\x02\x12\x1a\n\x16QUERY_OUTCOME_CANCELED\x10\x03\x42@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/query'
  _globals['_QUERYOUTCOME']._serialized_start=660
  _globals['_QUERYOUTCOME']._serialized_end=785
  _globals['_QUERYEXECUTED']._serialized_start=148
  _globals['_QUERYEXECUTED']._serialized_end=658
# @@protoc_insertion_point(module_scope)
