# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vscode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.fields import vscode_types_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_fields_dot_vscode__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vscode.proto\x12\x15v1.public.events.vsce\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a\x31\x64\x62tlabs/proto/public/v1/fields/vscode_types.proto\"\xe5\x03\n\x12\x45xtensionActivated\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x0f\n\x07os_name\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0cinit_success\x18\x06 \x01(\x08\x12\x12\n\ninit_error\x18\x07 \x01(\t\x12\x19\n\x11init_error_detail\x18\x08 \x01(\t\x12\x18\n\x10init_duration_ms\x18\t \x01(\x03\x12\x18\n\x10is_lsp_installed\x18\n \x01(\x08\x12\x1b\n\x13is_fusion_installed\x18\x0b \x01(\x08\x12\x13\n\x0b\x64\x62t_version\x18\x0c \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\r \x01(\t\x12\x14\n\x0cmodels_count\x18\x0e \x01(\x05\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x0f \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xe3\x04\n\x13\x45xtensionLspCompile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x05 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x62t_version\x18\x07 \x01(\t\x12\x17\n\x0f\x63ompile_success\x18\x08 \x01(\x08\x12;\n\x06\x65rrors\x18\t \x03(\x0b\x32+.v1.public.fields.vscode_types.CompileError\x12\x13\n\x0b\x64uration_ms\x18\n \x01(\x03\x12@\n\x0c\x63ompile_type\x18\x0b \x01(\x0e\x32*.v1.public.fields.vscode_types.CompileType\x12\x14\n\x0cmodels_count\x18\x0c \x01(\x05\x12\x16\n\x0euser_initiated\x18\r \x01(\x08\x12\x42\n\rcompile_cause\x18\x0e \x01(\x0e\x32+.v1.public.fields.vscode_types.CompileCause\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x0f \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x02\n\x18\x45xtensionUserStateChange\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x42\n\x10\x63hanged_to_state\x18\x04 \x01(\x0e\x32(.v1.public.fields.vscode_types.UserState\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xea\x01\n\x13\x45xtensionCtePreview\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf1\x01\n\x1a\x45xtensionLineageTabClicked\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xed\x01\n\x16\x45xtensionColumnLineage\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf0\x01\n\x19\x45xtensionShowCompiledFile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xeb\x01\n\x14\x45xtensionModelRename\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xec\x01\n\x15\x45xtensionColumnRename\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x87\x02\n\x16\x45xtensionUsedBuildMenu\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x18\n\x10selected_command\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8a\x02\n\x1d\x45xtensionGetSupportPopupShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x87\x02\n\x1a\x45xtensionGetSupportClicked\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x89\x02\n\x1c\x45xtensionGetSupportFormShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x95\x02\n(ExtensionGetSupportUnverifiedNoticeShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x9e\x02\n ExtensionGetSupportFormSubmitted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8d\x02\n ExtensionGetSupportFormCancelled\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8b\x02\n\x1e\x45xtensionGetSupportPanelClosed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xff\x01\n\x16\x45xtensionCompareViewed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x94\x02\n\x17\x45xtensionCompareStarted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\ncompare_id\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xdb\x02\n\x18\x45xtensionCompareFinished\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\ncompare_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x03\x12\x17\n\x0f\x63ompare_success\x18\x06 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x07 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x08 \x01(\t\x12\x10\n\x08\x65vent_id\x18\t \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8e\x02\n%ExtensionRegistrationMessageDismissed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xeb\x02\n\x18\x45xtensionRegisterStarted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12P\n\x0etrigger_method\x18\x06 \x01(\x0e\x32\x38.v1.public.fields.vscode_types.RegistrationTriggerMethod\x12\x16\n\x0e\x63orrelation_id\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd5\x02\n!ExtensionRegistrationUrlAttempted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12\x12\n\nurl_opened\x18\x06 \x01(\x08\x12\x1d\n\x15oauth_params_included\x18\x07 \x01(\x08\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xbf\x03\n\x1e\x45xtensionRegistrationCompleted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12N\n\x13registration_method\x18\x06 \x01(\x0e\x32\x31.v1.public.fields.vscode_types.RegistrationMethod\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t\x12\x12\n\naccount_id\x18\t \x01(\t\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_host\x18\x0b \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8d\x03\n\x1d\x45xtensionRegistrationTimedOut\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12P\n\x0etrigger_method\x18\x06 \x01(\x0e\x32\x38.v1.public.fields.vscode_types.RegistrationTriggerMethod\x12\x1b\n\x13timeout_duration_ms\x18\x07 \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xad\x03\n\x1c\x45xtensionRegistrationErrored\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12N\n\x13registration_method\x18\x06 \x01(\x0e\x32\x31.v1.public.fields.vscode_types.RegistrationMethod\x12\x12\n\nerror_type\x18\x07 \x01(\t\x12\x15\n\rerror_message\x18\x08 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\t \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\n \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x38Z6github.com/dbt-labs/proto-golang/v1/public/events/vsceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vscode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dbt-labs/proto-golang/v1/public/events/vsce'
  _globals['_EXTENSIONACTIVATED']._loaded_options = None
  _globals['_EXTENSIONACTIVATED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLSPCOMPILE']._loaded_options = None
  _globals['_EXTENSIONLSPCOMPILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONUSERSTATECHANGE']._loaded_options = None
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCTEPREVIEW']._loaded_options = None
  _globals['_EXTENSIONCTEPREVIEW']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLINEAGETABCLICKED']._loaded_options = None
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOLUMNLINEAGE']._loaded_options = None
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._loaded_options = None
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONMODELRENAME']._loaded_options = None
  _globals['_EXTENSIONMODELRENAME']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOLUMNRENAME']._loaded_options = None
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONUSEDBUILDMENU']._loaded_options = None
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTCLICKED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPAREVIEWED']._loaded_options = None
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPARESTARTED']._loaded_options = None
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPAREFINISHED']._loaded_options = None
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTERSTARTED']._loaded_options = None
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONERRORED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONACTIVATED']._serialized_start=220
  _globals['_EXTENSIONACTIVATED']._serialized_end=705
  _globals['_EXTENSIONLSPCOMPILE']._serialized_start=708
  _globals['_EXTENSIONLSPCOMPILE']._serialized_end=1319
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_start=1322
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_end=1629
  _globals['_EXTENSIONCTEPREVIEW']._serialized_start=1632
  _globals['_EXTENSIONCTEPREVIEW']._serialized_end=1866
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_start=1869
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_end=2110
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_start=2113
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_end=2350
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_start=2353
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_end=2593
  _globals['_EXTENSIONMODELRENAME']._serialized_start=2596
  _globals['_EXTENSIONMODELRENAME']._serialized_end=2831
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_start=2834
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_end=3070
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_start=3073
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_end=3336
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_start=3339
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_end=3605
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_start=3608
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_end=3871
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_start=3874
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_end=4139
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_start=4142
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_end=4419
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_start=4422
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_end=4708
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_start=4711
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_end=4980
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_start=4983
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_end=5250
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_start=5253
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_end=5508
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_start=5511
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_end=5787
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_start=5790
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_end=6137
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_start=6140
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_end=6410
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_start=6413
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_end=6776
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_start=6779
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_end=7120
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_start=7123
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_end=7570
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_start=7573
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_end=7970
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_start=7973
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_end=8402
# @@protoc_insertion_point(module_scope)
