# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/common/vortex_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/common/vortex_options.proto\x12\x10v1.public.common\x1a google/protobuf/descriptor.proto*\xa8\x02\n\x16VortexIcebergNamespace\x12(\n$VORTEX_ICEBERG_NAMESPACE_UNSPECIFIED\x10\x00\x12,\n(VORTEX_ICEBERG_NAMESPACE_COST_MONITORING\x10\x01\x12#\n\x1fVORTEX_ICEBERG_NAMESPACE_FUSION\x10\x02\x12&\n\"VORTEX_ICEBERG_NAMESPACE_TELEMETRY\x10\x03\x12 \n\x1cVORTEX_ICEBERG_NAMESPACE_DLQ\x10\x04\x12#\n\x1fVORTEX_ICEBERG_NAMESPACE_MANTLE\x10\x05\x12\"\n\x1eVORTEX_ICEBERG_NAMESPACE_CODEX\x10\x06:h\n\x10vortex_namespace\x12\x1f.google.protobuf.MessageOptions\x18\xeb\xd4\x03 \x01(\x0e\x32(.v1.public.common.VortexIcebergNamespace\x88\x01\x01:?\n\x11vortex_table_name\x12\x1f.google.protobuf.MessageOptions\x18\xec\xd4\x03 \x01(\t\x88\x01\x01:D\n\x16vortex_partition_field\x12\x1f.google.protobuf.MessageOptions\x18\xed\xd4\x03 \x01(\r\x88\x01\x01:E\n\x17vortex_write_to_iceberg\x12\x1f.google.protobuf.MessageOptions\x18\xef\xd4\x03 \x01(\x08\x88\x01\x01:<\n\x0evortex_enabled\x12\x1f.google.protobuf.MessageOptions\x18\xf0\xd4\x03 \x01(\x08\x88\x01\x01\x42\x33Z1github.com/dbt-labs/proto-golang/v1/public/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.common.vortex_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/dbt-labs/proto-golang/v1/public/common'
  _globals['_VORTEXICEBERGNAMESPACE']._serialized_start=108
  _globals['_VORTEXICEBERGNAMESPACE']._serialized_end=404
# @@protoc_insertion_point(module_scope)
