# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/deps/deps.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/deps/deps.proto\x12\x1cv1.public.events.fusion.deps\"\xb6\x01\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12?\n\x0cpackage_type\x18\x02 \x01(\x0e\x32).v1.public.events.fusion.deps.PackageType\x12\x1c\n\x0fpackage_version\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x04 \x01(\tB\x12\n\x10_package_version\"\x8c\x02\n\x14\x44\x65psPackageInstalled\x12\x19\n\x0cpackage_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\x0cpackage_type\x18\x02 \x01(\x0e\x32).v1.public.events.fusion.deps.PackageType\x12\x1c\n\x0fpackage_version\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13package_url_or_path\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x05 \x01(\tB\x0f\n\r_package_nameB\x12\n\x10_package_versionB\x16\n\x14_package_url_or_path\"1\n\x18\x44\x65psAllPackagesInstalled\x12\x15\n\rpackage_count\x18\x01 \x01(\x04*\xa3\x01\n\x0bPackageType\x12\x1c\n\x18PACKAGE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10PACKAGE_TYPE_HUB\x10\x01\x12\x14\n\x10PACKAGE_TYPE_GIT\x10\x02\x12\x16\n\x12PACKAGE_TYPE_LOCAL\x10\x03\x12\x18\n\x14PACKAGE_TYPE_PRIVATE\x10\x04\x12\x18\n\x14PACKAGE_TYPE_TARBALL\x10\x05\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/depsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.deps.deps_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/deps'
  _globals['_PACKAGETYPE']._serialized_start=595
  _globals['_PACKAGETYPE']._serialized_end=758
  _globals['_DEPSADDPACKAGE']._serialized_start=88
  _globals['_DEPSADDPACKAGE']._serialized_end=270
  _globals['_DEPSPACKAGEINSTALLED']._serialized_start=273
  _globals['_DEPSPACKAGEINSTALLED']._serialized_end=541
  _globals['_DEPSALLPACKAGESINSTALLED']._serialized_start=543
  _globals['_DEPSALLPACKAGESINSTALLED']._serialized_end=592
# @@protoc_insertion_point(module_scope)
